@@ -14,8 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Winfried Bruegmann
-    							2016,2017,2018,2019 Thomas Eickert
+    Copyright (c) 2008-2026 Winfried Bruegmann
+    							2016-2019 Thomas Eickert
 ****************************************************************************************/
 package gde;
 
@@ -108,7 +108,7 @@ public class GDE {
 	private static boolean									isWithUi													= false;
 
 	// ****** begin global constants section *******
-	public static final String							VERSION														= "Version 4.0.1"; // do not use more than 3 digits, check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
+	public static final String							VERSION														= "Version 4.0.2"; // do not use more than 3 digits, check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
 	public static final int									VERSION_NUMBER										= GDE.VERSION.contains("beta") 
 															? Integer.parseInt(GDE.VERSION.substring(8, GDE.VERSION.indexOf("beta")-1).replace(GDE.STRING_DOT, GDE.STRING_EMPTY).trim()) - 1
 															: Integer.parseInt(GDE.VERSION.substring(8, GDE.VERSION.length()).replace(GDE.STRING_DOT, GDE.STRING_EMPTY).trim());
@@ -127,7 +127,8 @@ public class GDE {
 	public static final boolean							IS_MAC_COCOA											= GDE.IS_MAC && System.getProperty("DO_NOT_USE_COCOA") == null && SWT.getPlatform().toLowerCase().startsWith("cocoa");			//$NON-NLS-1$ //$NON-NLS-2$
 	public static final boolean							IS_ARCH_DATA_MODEL_64							= System.getProperty("sun.arch.data.model").equals("64");																																		//$NON-NLS-1$ //$NON-NLS-2$
 	public static final boolean							IS_OS_ARCH_ARM										= System.getProperty("os.arch").toLowerCase().startsWith("arm") || System.getProperty("os.arch").toLowerCase().startsWith("aarch");	//$NON-NLS-1$ //$NON-NLS-2$
-	public static final boolean							isSystemDarkTheme									= GDE.isSystemDarkTheme();
+	public static final boolean							IS_SYSTEM_DARK_THEME							= GDE.isSystemDarkTheme();
+	public static final String							DOWNLOAD_UPDATE_URL								= "https://download-mirror.savannah.gnu.org/releases/dataexplorer/";
 
 	/** Depends on the Operating System type. Is empty if no valid OS. */
 	public static final String							APPL_HOME_PATH										= GDE.IS_WINDOWS
@@ -463,7 +464,7 @@ public class GDE {
 	 */
 	public static void main(String[] args) {
 		final String $METHOD_NAME = "main"; //$NON-NLS-1$
-		log.log(Level.FINER, "main    start");
+		
 		try {
 			System.setProperty("https.protocols", "SSLv3,TLSv1,TLSv1.1,TLSv1.2");
 			System.setProperty("file.encoding", "UTF-8");
@@ -479,8 +480,8 @@ public class GDE {
 				}
 			};
 			GDE.settingsThread.start();
-			
-			log.log(Level.INFO, "main start");
+
+			log.log(Level.INFO, "main start " + StringHelper.arrayToString(args));
 			String inputFilePath = GDE.STRING_EMPTY;
 
 			Display.setAppName(GDE.NAME_LONG);
