@@ -346,6 +346,12 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 					throw new LibUsbException("Unable to read device descriptor", result);
 				else if (descriptor.idVendor() == vendorId && descriptor.idProduct() == productId) {
 					if (productString == null || productString.length() == 0) {
+						DeviceHandle handle = new DeviceHandle();
+						result = LibUsb.open(libUsbDevice, handle);
+						if (result < 0) {
+							log.log(Level.WARNING, String.format("Unable to open device: %s. " + "Continuing without device handle.", LibUsb.strError(result)));
+							handle = null;
+						}
 						libUsbDevices.add(libUsbDevice);
 					} else { //find device with matching product string
 						DeviceHandle handle = new DeviceHandle();
@@ -415,32 +421,7 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 
 		try {
 			for (Device libUsbDevice : list) {
-				DeviceDescriptor descriptor = new DeviceDescriptor();
-				result = LibUsb.getDeviceDescriptor(libUsbDevice, descriptor);
-				if (result == LibUsb.SUCCESS) {
-					log.log(Level.INFO, libUsbDevice.toString());
-					// Try to open the device. This may fail because user has no
-					// permission to communicate with the device. This is not
-					// important for the dumps, we are just not able to resolve string
-					// descriptor numbers to strings in the descriptor dumps.
-					DeviceHandle handle = new DeviceHandle();
-					result = LibUsb.open(libUsbDevice, handle);
-					if (result < 0) {
-						log.log(Level.WARNING, String.format("Unable to open device: %s. " + "Continuing without device handle.", LibUsb.strError(result)));
-						handle = null;
-					}
-
-					// Dump the device descriptor
-					log.log(Level.INFO, descriptor.dump(handle));
-
-					// Dump all configuration descriptors
-					dumpConfigurationDescriptors(libUsbDevice, descriptor.bNumConfigurations());
-
-					// Close the device if it was opened
-					if (handle != null) {
-						LibUsb.close(handle);
-					}
-				}
+				DumpDevicesLibUsb.dumpDevice(libUsbDevice);
 			}
 		}
 		finally {
@@ -563,8 +544,7 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 					fondUsbDevices.put(usbDeviceString, usbDevice);
 				}
 				catch (UnsupportedEncodingException | UsbDisconnectedException | UsbException e) {
-					// TODO Auto-generated catch block
-					e.printStackTrace();
+					log.log(Level.SEVERE, e.getMessage(), e);
 				}
 			}
 			UsbDevice selUsbDevice = null;
@@ -603,7 +583,7 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 		DeviceHandle libUsbDeviceHandle = new DeviceHandle();
 		byte ifaceId = activeDevice.getUsbInterface();
 
-		if (log.isLoggable(Level.FINE)) {
+		if (log.isLoggable(Level.INFO)) {
 			dumpLibUsbDevices();
 		}
 		
@@ -637,20 +617,29 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 					handle = null;
 				}
 				String descriptorString = descriptor.dump(handle);
-				if (descriptorString.contains("iProduct") && descriptorString.contains(activeDevice.getUsbProductString()) && descriptorString.contains("iSerial")) {
-					String usbDeviceString = LibUsb.getStringDescriptor(handle, descriptor.iProduct()) + " S/N " + LibUsb.getStringDescriptor(handle, descriptor.iSerialNumber());
-					myUsbDevices.put(usbDeviceString, libUsbDevice);
-				}				
-				LibUsb.close(handle);
+				String productString = activeDevice.getUsbProductString();
+				if (productString != null) {
+					if (descriptorString.contains("iProduct") && descriptorString.contains(activeDevice.getUsbProductString()) && descriptorString.contains("iSerial")) {
+						String usbDeviceString = LibUsb.getStringDescriptor(handle, descriptor.iProduct()) + " S/N " + LibUsb.getStringDescriptor(handle, descriptor.iSerialNumber());
+						myUsbDevices.put(usbDeviceString, libUsbDevice);
+					}				
+					LibUsb.close(handle);
+				} else {
+					if (descriptorString.contains("iProduct") && descriptorString.contains("iSerial")) {
+						String usbDeviceString = LibUsb.getStringDescriptor(handle, descriptor.iProduct()) + " S/N " + LibUsb.getStringDescriptor(handle, descriptor.iSerialNumber());
+						myUsbDevices.put(usbDeviceString, libUsbDevice);
+					}				
+					LibUsb.close(handle);
+				}
 			}
 			if (myUsbDevices.size() > 0 && selectedUsbDevice == null) {
 				//several identical USB HID  found, manual select usbDevice
-				selectedUsbDevice = (Device) new LibUsbDeviceSelectionDialog(myUsbDevices).open();
+				DeviceUsbPortImpl.selectedUsbDevice = (Device) new LibUsbDeviceSelectionDialog(myUsbDevices).open();
 				claimLibUsbDevice(selectedUsbDevice, libUsbDeviceHandle, ifaceId);
 			}
 			else if (myUsbDevices.size() > 0 && selectedUsbDevice != null) {
 				//several identical USB HID  found, selected usbDevice available for this GDE instance
-				claimLibUsbDevice(selectedUsbDevice, libUsbDeviceHandle, ifaceId);
+				claimLibUsbDevice(DeviceUsbPortImpl.selectedUsbDevice, libUsbDeviceHandle, ifaceId);
 			}
 			else
 				throw new UsbException(String.format("%s\n===>>>  %s", Messages.getString(MessageIds.GDE_MSGE0050), activeDevice.getUsbProductString()));
@@ -666,8 +655,8 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 		if (libUsbDevice == null) throw new UsbException(Messages.getString(gde.messages.MessageIds.GDE_MSGE0050));
 		result = LibUsb.open(libUsbDevice, libUsbDeviceHandle);
 		if (result < 0) {
-			LibUsb.close(libUsbDeviceHandle);
 			log.log(Level.SEVERE, String.format("Unable to open device: %s.", LibUsb.strError(result)));
+			LibUsb.close(libUsbDeviceHandle);
 			throw new UsbClaimException(new LibUsbException(result).getMessage());
 		}
 		
@@ -685,6 +674,7 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 		result = LibUsb.claimInterface(libUsbDeviceHandle, ifaceId);
 		if (result < 0) {
 			LibUsb.close(libUsbDeviceHandle);
+			DeviceUsbPortImpl.selectedUsbDevice = null;
 			log.log(Level.SEVERE, String.format("Unable to claim device: %s.", LibUsb.strError(result)));
 			throw new UsbClaimException(new LibUsbException(result).getMessage());
 		}
