@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Winfried Bruegmann
+    Copyright (c) 2008-2026 Winfried Bruegmann
 ****************************************************************************************/
 package gde.data;
 
@@ -384,7 +384,7 @@ public class Channel extends HashMap<String, RecordSet> {
 					//smooth voltage curve
 					recordSet.setSmoothVoltageCurve(Boolean.valueOf(this.template.getProperty(RecordSet.SMOOTH_VOLTAGE_CURVE, "false"))); //$NON-NLS-1$
 					// time grid
-					String color = GDE.isSystemDarkTheme ? "255,255,255" : this.template.getProperty(RecordSet.TIME_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
+					String color = GDE.IS_SYSTEM_DARK_THEME ? "255,255,255" : this.template.getProperty(RecordSet.TIME_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
 					r = Integer.valueOf(color.split(GDE.STRING_COMMA)[0].trim()).intValue();
 					g = Integer.valueOf(color.split(GDE.STRING_COMMA)[1].trim()).intValue();
 					b = Integer.valueOf(color.split(GDE.STRING_COMMA)[2].trim()).intValue();
@@ -392,7 +392,7 @@ public class Channel extends HashMap<String, RecordSet> {
 					recordSet.setTimeGridLineStyle(Integer.valueOf(this.template.getProperty(RecordSet.TIME_GRID_LINE_STYLE, GDE.STRING_EMPTY + SWT.LINE_DOT)).intValue());
 					recordSet.setTimeGridType(Integer.valueOf(this.template.getProperty(RecordSet.TIME_GRID_TYPE, "0")).intValue()); //$NON-NLS-1$
 					// curve grid
-					color = GDE.isSystemDarkTheme ? "255,255,255" : this.template.getProperty(RecordSet.VALUE_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
+					color = GDE.IS_SYSTEM_DARK_THEME ? "255,255,255" : this.template.getProperty(RecordSet.VALUE_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
 					r = Integer.valueOf(color.split(GDE.STRING_COMMA)[0].trim()).intValue();
 					g = Integer.valueOf(color.split(GDE.STRING_COMMA)[1].trim()).intValue();
 					b = Integer.valueOf(color.split(GDE.STRING_COMMA)[2].trim()).intValue();
@@ -480,7 +480,7 @@ public class Channel extends HashMap<String, RecordSet> {
 				//smooth voltage curve
 				recordSet.setSmoothVoltageCurve(Boolean.parseBoolean(this.template.getProperty(RecordSet.SMOOTH_VOLTAGE_CURVE, "false"))); //$NON-NLS-1$
 				// time grid
-				String color = GDE.isSystemDarkTheme ? "255,255,255" : this.template.getProperty(RecordSet.TIME_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
+				String color = GDE.IS_SYSTEM_DARK_THEME ? "255,255,255" : this.template.getProperty(RecordSet.TIME_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
 				r = Integer.parseInt(color.split(GDE.STRING_COMMA)[0].trim());
 				g = Integer.parseInt(color.split(GDE.STRING_COMMA)[1].trim());
 				b = Integer.parseInt(color.split(GDE.STRING_COMMA)[2].trim());
@@ -488,7 +488,7 @@ public class Channel extends HashMap<String, RecordSet> {
 				recordSet.setTimeGridLineStyle(Integer.parseInt(this.template.getProperty(RecordSet.TIME_GRID_LINE_STYLE, GDE.STRING_EMPTY + SWT.LINE_DOT)));
 				recordSet.setTimeGridType(Integer.parseInt(this.template.getProperty(RecordSet.TIME_GRID_TYPE, "0"))); //$NON-NLS-1$
 				// curve grid
-				color = GDE.isSystemDarkTheme ? "255,255,255" : this.template.getProperty(RecordSet.VALUE_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
+				color = GDE.IS_SYSTEM_DARK_THEME ? "255,255,255" : this.template.getProperty(RecordSet.VALUE_GRID_COLOR, "128,128,128"); //$NON-NLS-1$
 				r = Integer.parseInt(color.split(GDE.STRING_COMMA)[0].trim());
 				g = Integer.parseInt(color.split(GDE.STRING_COMMA)[1].trim());
 				b = Integer.parseInt(color.split(GDE.STRING_COMMA)[2].trim());
