@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Winfried Bruegmann
+    Copyright (c) 2008-2026 Winfried Bruegmann
 ****************************************************************************************/
 package gde.data;
 
@@ -1648,7 +1648,7 @@ public final class RecordSet extends AbstractRecordSet {
 			tmpValue = recordSetProps.get(TIME_GRID_LINE_STYLE);
 			if (tmpValue != null && tmpValue.length() > 0) this.timeGridLineStyle = Integer.valueOf(tmpValue.trim()).intValue();
 			tmpValue = recordSetProps.get(TIME_GRID_COLOR);
-			if (tmpValue != null && tmpValue.length() > 5) this.timeGridColor = GDE.isSystemDarkTheme ? DataExplorer.getInstance().COLOR_BLACK 
+			if (tmpValue != null && tmpValue.length() > 5) this.timeGridColor = GDE.IS_SYSTEM_DARK_THEME ? DataExplorer.getInstance().COLOR_BLACK 
 					: SWTResourceManager.getColor(Integer.valueOf(tmpValue.split(GDE.STRING_COMMA)[0]),
 					Integer.valueOf(tmpValue.split(GDE.STRING_COMMA)[1]), Integer.valueOf(tmpValue.split(GDE.STRING_COMMA)[2]));
 
@@ -1676,7 +1676,7 @@ public final class RecordSet extends AbstractRecordSet {
 			tmpValue = recordSetProps.get(VALUE_GRID_LINE_STYLE);
 			if (tmpValue != null && tmpValue.length() > 0) this.valueGridLineStyle = Integer.valueOf(tmpValue.trim()).intValue();
 			tmpValue = recordSetProps.get(VALUE_GRID_COLOR);
-			if (tmpValue != null && tmpValue.length() > 5) this.valueGridColor = GDE.isSystemDarkTheme ? DataExplorer.getInstance().COLOR_BLACK 
+			if (tmpValue != null && tmpValue.length() > 5) this.valueGridColor = GDE.IS_SYSTEM_DARK_THEME ? DataExplorer.getInstance().COLOR_BLACK 
 					: SWTResourceManager.getColor(Integer.valueOf(tmpValue.split(GDE.STRING_COMMA)[0]),
 					Integer.valueOf(tmpValue.split(GDE.STRING_COMMA)[1]), Integer.valueOf(tmpValue.split(GDE.STRING_COMMA)[2]));
 
