@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Winfried Bruegmann
+    Copyright (c) 2008-2026 Winfried Bruegmann
 ****************************************************************************************/
 package gde.ui.dialog;
 
@@ -24,6 +24,8 @@ import java.util.logging.Logger;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CCombo;
 import org.eclipse.swt.custom.CLabel;
+import org.eclipse.swt.events.ControlEvent;
+import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.HelpEvent;
@@ -150,6 +152,18 @@ public class CellVoltageValuesDialog extends org.eclipse.swt.widgets.Dialog {
 					CellVoltageValuesDialog.this.application.updateCellVoltageLimitsSelector();
 				}
 			});
+			this.dialogShell.addControlListener(new ControlListener() {
+				
+				@Override
+				public void controlResized(ControlEvent e) {
+					CellVoltageValuesDialog.this.dialogShell.setSize(380, 380);
+				}
+				
+				@Override
+				public void controlMoved(ControlEvent e) {
+					// nothing to do
+				}
+			});
 			{
 				this.presetsGroup = new Group(this.dialogShell, SWT.BORDER);
 				this.presetsGroup.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
