@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Winfried Bruegmann
+    Copyright (c) 2008-2026 Winfried Bruegmann
 ****************************************************************************************/
 package gde.ui.dialog;
 
@@ -43,6 +43,8 @@ import javax.print.attribute.standard.JobName;
 import javax.print.attribute.standard.OrientationRequested;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.ControlEvent;
+import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.PaintEvent;
@@ -156,6 +158,19 @@ public class PrintSelectionDialog extends org.eclipse.swt.widgets.Dialog {
 					PrintSelectionDialog.this.application.resetShellIcon();
 				}
 			});
+			this.dialogShell.addControlListener(new ControlListener() {
+				
+				@Override
+				public void controlResized(ControlEvent e) {
+					dialogShell.setSize(400, 400);
+				}
+				
+				@Override
+				public void controlMoved(ControlEvent e) {
+					// nothing to do
+				}
+			});
+
 			{
 				this.headerButton = new Button(this.dialogShell, SWT.CHECK | SWT.LEFT);
 				this.headerButton.setText(Messages.getString(MessageIds.GDE_MSGT0456));
