@@ -14,10 +14,11 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
     
-    Copyright (c) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Winfried Bruegmann
+    Copyright (c) 2008-2026 Winfried Bruegmann
 ****************************************************************************************/
 package gde.utils;
 
+import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.Arrays;
 import java.util.Date;
@@ -142,6 +143,17 @@ public class StringHelper {
 		return new SimpleDateFormat("yyyy-MM-dd").format(new Date()); //$NON-NLS-1$
 	}
 
+	/**
+	 * method to get date from given formated date string
+	 */
+	public static Date getDate(String dateString) {
+		try {
+			return new SimpleDateFormat("yyyy-MM-dd").parse(dateString);
+		}
+		catch (ParseException e) {
+			return new Date();
+		}
+	}
 	/**
 	 * method to get formated time by given format string and time in millis seconds
 	 */
@@ -1042,7 +1054,7 @@ public class StringHelper {
 		for (Object object : inputArray) {
 			sb.append(object).append(GDE.STRING_COMMA_BLANK);
 		}
-		sb.deleteCharAt(sb.length()-2);
+		if (inputArray.length > 2) sb.deleteCharAt(sb.length()-2);
 		return sb.toString();
 	}
 	
