@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with GNU DataExplorer.  If not, see <https://www.gnu.org/licenses/>.
 
-    Copyright (c) 2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Winfried Bruegmann
+    Copyright (c) 2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025,2026 Winfried Bruegmann
 ****************************************************************************************/
 package gde.device.smmodellbau;
 
@@ -75,11 +75,11 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 	CCombo									heightMaxAlarmCombo, speedMaxAlarmCombo, speedMinAlarmCombo, distanceMaxCombo, distanceMinCombo, tripLengthCombo, voltageRxCombo;
 	CLabel									heightMaxAlarmLabel, speedAlarmLabel, distanceMaxLabel, distanceMinLabel, tripLengthLabel, voltageRxLabel;
 
-	CLabel									frskyIdLabel;
+	CLabel									frskyTxIdLabel, frskyInstanceIdLabel, tekCompensationLabel, tekCompensationUnitLabel;
 	Button									fixSerialNumberButton, fixStartPositionButton;
 	Button									hottDeadBandButton;
 	Button									robbeTBoxButton;
-	CCombo									frskyIdCombo;
+	CCombo									frskyTxIdCombo, frskyInstanceIdCombo, tekCompensationCombo;
 
 	final SetupReaderWriter	configuration;
 	final String[]					languageValues	= {"Deutsch", "English"};
@@ -110,8 +110,12 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 	final String[]					telemetrieTypes	= { " - - - ", " Futaba", " JR DMSS", " HoTT", " JetiDuplex", " M-Link", " FrSky", " Spektrum", " P2Bus" };
 	final String[]					varioFactors;
 	final String[]					varioFilters		= Messages.getString(MessageIds.GDE_MSGT2019).split(GDE.STRING_COMMA);
-	final String[]					frskyIDs				= { " 0x00", " 0xA1", " 0x22", " 0x83", " 0xE4", " 0x45", " 0xC6", " 0x67", " 0x48", " 0xE9", " 0x6A", " 0xCB", " 0xAC", " 0x0D", " 0x8E",
-			" 0x2F", " 0xD0", " 0x71", " 0xF2", " 0x53", " 0x34", " 0x95", " 0x16", " 0xB7", " 0x98", " 0x39", " 0xBA", " 0x1B" };
+	//SensorID 0x01-1B, instance 0x0-0xF; ID am Sender = (SensorID-1 | AppID | instance)
+	final String[]					frskySensorIDs	= { " 0x00", " 0x01", " 0x02", " 0x03", " 0x04", " 0x05", " 0x06", " 0x07", " 0x08", " 0x09", " 0x0A", " 0x0B", " 0x0C", " 0x0D", " 0x0E",
+			" 0x0F", " 0x10", " 0x11", " 0x12", " 0x13", " 0x14", " 0x15", " 0x16", " 0x17", " 0x18", " 0x19", " 0x1A", " 0x1B" };
+	final String[]					frskyInstanceIDs= { " 0x00", " 0x01", " 0x02", " 0x03", " 0x04", " 0x05", " 0x06", " 0x07", " 0x08", " 0x09", " 0x0A", " 0x0B", " 0x0C", " 0x0D", " 0x0E", "0x0F"};
+	final String[] 					tekCompensationValues = new String[41];
+	
 
 	/**
 	 * constructor configuration panel 1
@@ -131,6 +135,10 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 			sb.append(String.format(Locale.ENGLISH, " %2.1f ,", 1 + i / 10.0));
 		}
 		this.varioFactors = sb.toString().split(GDE.STRING_COMMA);
+		int factor = 80;
+		for (int i=0; i<41; ++i) {
+			this.tekCompensationValues[i] = ""+(factor + i);
+		}
 		initGUI();
 		updateValues();
 	}
@@ -155,10 +163,12 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 		this.modusDistanceCombo.select(this.configuration.modusDistance);
 		this.telemetryTypeCombo.select(this.configuration.telemetryType);
 		this.minMaxRxCombo.select(this.configuration.rxControl);
-		this.frskyIdCombo.select(this.configuration.frskyAddr - 1);
+		this.frskyTxIdCombo.select(this.configuration.frskySensorAddr - 1);
+		this.frskyInstanceIdCombo.select(this.configuration.frskyInstanceId);
 		this.fixSerialNumberButton.setSelection(this.configuration.serialNumberFix == 1 ? true : false);
 		this.hottDeadBandButton.setSelection(this.configuration.isHottDeadBand == 0 ? true : false);
 		this.robbeTBoxButton.setSelection(this.configuration.robbe_T_Box == 1 ? true : false);
+		this.tekCompensationCombo.select(this.configuration.tekCompensation + 20);
 
 		this.heightMaxAlarmButton.setSelection((this.configuration.telemetryAlarms & SetupReaderWriter.TEL_ALARM_HEIGHT) > 0);
 		this.heightMaxAlarmCombo.setText(String.format("%5d", this.configuration.heightAlarm)); //$NON-NLS-1$
@@ -178,8 +188,10 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 	}
 
 	public void changeVisibility() {
-		this.frskyIdLabel.setVisible(false);
-		this.frskyIdCombo.setVisible(false);
+		this.frskyTxIdLabel.setVisible(false);
+		this.frskyTxIdCombo.setVisible(false);
+		this.frskyInstanceIdLabel.setVisible(false);
+		this.frskyInstanceIdCombo.setVisible(false);
 		this.hottDeadBandButton.setVisible(false);
 		this.hottSpeedTypeLabel.setVisible(false);
 		this.hottSpeedTypeCombo.setVisible(false);
@@ -217,8 +229,10 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 				}
 				break;
 			case 6: //FrSky
-				this.frskyIdLabel.setVisible(true);
-				this.frskyIdCombo.setVisible(true);
+				this.frskyTxIdLabel.setVisible(true);
+				this.frskyTxIdCombo.setVisible(true);
+				this.frskyInstanceIdLabel.setVisible(true);
+				this.frskyInstanceIdCombo.setVisible(true);
 				break;
 			case 5: //M-Link
 				if (GPSLoggerSetupConfiguration2.mLinkGroupStatic != null) {
@@ -262,7 +276,7 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 				gpsLoggerGroupLData.left = new FormAttachment(0, 1000, 10);
 				gpsLoggerGroupLData.top = new FormAttachment(0, 1000, 5);
 				gpsLoggerGroupLData.width = 290;
-				gpsLoggerGroupLData.height = GDE.IS_MAC ? 440 : 470;
+				gpsLoggerGroupLData.height = GDE.IS_MAC ? 450 : 495;
 				RowLayout gpsLoggerGroupLayout = new RowLayout(org.eclipse.swt.SWT.HORIZONTAL);
 				this.gpsLoggerGroup.setLayout(gpsLoggerGroupLayout);
 				this.gpsLoggerGroup.setLayoutData(gpsLoggerGroupLData);
@@ -439,36 +453,68 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 						});
 					}
 					{
-						this.frskyIdLabel = new CLabel(this.addonComposite, SWT.RIGHT);
+						this.frskyTxIdLabel = new CLabel(this.addonComposite, SWT.RIGHT);
 						FormData frskyIdLabelLData = new FormData();
 						frskyIdLabelLData.width = 130;
 						frskyIdLabelLData.height = 18;
 						frskyIdLabelLData.left = new FormAttachment(0, 1000, 0);
 						frskyIdLabelLData.top = new FormAttachment(0, 1000, 0);
-						this.frskyIdLabel.setLayoutData(frskyIdLabelLData);
-						this.frskyIdLabel.setText(Messages.getString(MessageIds.GDE_MSGT2079));
-						this.frskyIdLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
+						this.frskyTxIdLabel.setLayoutData(frskyIdLabelLData);
+						this.frskyTxIdLabel.setText("Sensor ID");
+						this.frskyTxIdLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 					}
 					{
-						this.frskyIdCombo = new CCombo(this.addonComposite, SWT.BORDER);
+						this.frskyTxIdCombo = new CCombo(this.addonComposite, SWT.BORDER);
 						FormData sensorTypeComboLData = new FormData();
 						sensorTypeComboLData.width = COMBO_WIDTH;
 						sensorTypeComboLData.height = COMBO_HEIGHT;
 						sensorTypeComboLData.left = new FormAttachment(0, 1000, 133);
 						sensorTypeComboLData.top = new FormAttachment(0, 1000, 0);
-						this.frskyIdCombo.setLayoutData(sensorTypeComboLData);
-						this.frskyIdCombo.setItems(this.frskyIDs);
-						this.frskyIdCombo.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
-						this.frskyIdCombo.setEditable(false);
-						this.frskyIdCombo.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
-						this.frskyIdCombo.addSelectionListener(new SelectionAdapter() {
+						this.frskyTxIdCombo.setLayoutData(sensorTypeComboLData);
+						this.frskyTxIdCombo.setItems(this.frskySensorIDs);
+						this.frskyTxIdCombo.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
+						this.frskyTxIdCombo.setEditable(false);
+						this.frskyTxIdCombo.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
+						this.frskyTxIdCombo.addSelectionListener(new SelectionAdapter() {
 							@Override
 							public void widgetSelected(SelectionEvent evt) {
 								GPSLoggerSetupConfiguration1.log.log(Level.FINEST, "sensorTypeCombo.widgetSelected, event=" + evt); //$NON-NLS-1$
-								GPSLoggerSetupConfiguration1.this.configuration.frskyAddr = (short) (GPSLoggerSetupConfiguration1.this.frskyIdCombo.getSelectionIndex() + 1);
+								GPSLoggerSetupConfiguration1.this.configuration.frskySensorAddr = (short) (GPSLoggerSetupConfiguration1.this.frskyTxIdCombo.getSelectionIndex() + 1);
 								GPSLoggerSetupConfiguration1.this.dialog.enableSaveConfigurationButton(true);
 							}
 						});
+						{
+							this.frskyInstanceIdLabel = new CLabel(this.addonComposite, SWT.RIGHT);
+							FormData instanceIdLabelLData = new FormData();
+							instanceIdLabelLData.width = 130;
+							instanceIdLabelLData.height = 18;
+							instanceIdLabelLData.left = new FormAttachment(0, 1000, 0);
+							instanceIdLabelLData.top = new FormAttachment(0, 1000, 22);
+							this.frskyInstanceIdLabel.setLayoutData(instanceIdLabelLData);
+							this.frskyInstanceIdLabel.setText(Messages.getString(MessageIds.GDE_MSGT2079));
+							this.frskyInstanceIdLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
+						}
+						{
+							this.frskyInstanceIdCombo = new CCombo(this.addonComposite, SWT.BORDER);
+							FormData instanceTypeComboLData = new FormData();
+							instanceTypeComboLData.width = COMBO_WIDTH;
+							instanceTypeComboLData.height = COMBO_HEIGHT;
+							instanceTypeComboLData.left = new FormAttachment(0, 1000, 133);
+							instanceTypeComboLData.top = new FormAttachment(0, 1000, 22);
+							this.frskyInstanceIdCombo.setLayoutData(instanceTypeComboLData);
+							this.frskyInstanceIdCombo.setItems(this.frskyInstanceIDs);
+							this.frskyInstanceIdCombo.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
+							this.frskyInstanceIdCombo.setEditable(false);
+							this.frskyInstanceIdCombo.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
+							this.frskyInstanceIdCombo.addSelectionListener(new SelectionAdapter() {
+								@Override
+								public void widgetSelected(SelectionEvent evt) {
+									GPSLoggerSetupConfiguration1.log.log(Level.FINEST, "instanceCombo.widgetSelected, event=" + evt); //$NON-NLS-1$
+									GPSLoggerSetupConfiguration1.this.configuration.frskyInstanceId = (byte) (GPSLoggerSetupConfiguration1.this.frskyInstanceIdCombo.getSelectionIndex());
+									GPSLoggerSetupConfiguration1.this.dialog.enableSaveConfigurationButton(true);
+								}
+							});
+						}
 					}
 					this.addonComposite.layout();
 				}
@@ -961,12 +1007,51 @@ public class GPSLoggerSetupConfiguration1 extends Composite {
 						}
 					});
 				}
+				{
+					this.tekCompensationLabel = new CLabel(this.gpsLoggerGroup, SWT.RIGHT);
+					RowData tekCompensationLData = new RowData();
+					tekCompensationLData.width = 130;
+					tekCompensationLData.height = 18;
+					this.tekCompensationLabel.setLayoutData(tekCompensationLData);
+					this.tekCompensationLabel.setText(Messages.getString(MessageIds.GDE_MSGI2006));
+					this.tekCompensationLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
+					this.tekCompensationLabel.setToolTipText(Messages.getString(MessageIds.GDE_MSGI2007));
+				}
+				{
+					this.tekCompensationCombo = new CCombo(this.gpsLoggerGroup, SWT.BORDER);
+					RowData minMaxRxComboLData = new RowData();
+					minMaxRxComboLData.width = COMBO_WIDTH;
+					minMaxRxComboLData.height = COMBO_HEIGHT;
+					this.tekCompensationCombo.setLayoutData(minMaxRxComboLData);
+					this.tekCompensationCombo.setItems(this.tekCompensationValues);
+					this.tekCompensationCombo.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
+					this.tekCompensationCombo.setEditable(false);
+					this.tekCompensationCombo.setBackground(SWTResourceManager.getColor(SWT.COLOR_WHITE));
+					this.tekCompensationCombo.addSelectionListener(new SelectionAdapter() {
+						@Override
+						public void widgetSelected(SelectionEvent evt) {
+							GPSLoggerSetupConfiguration1.log.log(Level.FINEST, "tekCompensationCombo.widgetSelected, event=" + evt); //$NON-NLS-1$
+							GPSLoggerSetupConfiguration1.this.configuration.tekCompensation = (byte) (Byte.parseByte(GPSLoggerSetupConfiguration1.this.tekCompensationCombo.getText())-100);
+							GPSLoggerSetupConfiguration1.this.dialog.enableSaveConfigurationButton(true);
+						}
+					});
+				}
+				{
+					this.tekCompensationUnitLabel = new CLabel(this.gpsLoggerGroup, SWT.CENTER);
+					RowData timeZoneUnitLabelLData = new RowData();
+					timeZoneUnitLabelLData.width = 79;
+					timeZoneUnitLabelLData.height = 18;
+					this.tekCompensationUnitLabel.setLayoutData(timeZoneUnitLabelLData);
+					this.tekCompensationUnitLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
+					this.tekCompensationUnitLabel.setText("[%]");
+				}
+
 			}
 			{
 				this.gpsTelemertieAlarmGroup = new Group(this, SWT.NONE);
 				FormData gpsTelemertieGroupLData = new FormData();
 				gpsTelemertieGroupLData.left = new FormAttachment(0, 1000, 10);
-				gpsTelemertieGroupLData.top = new FormAttachment(0, 1000, 490);
+				gpsTelemertieGroupLData.top = new FormAttachment(0, 1000, GDE.IS_MAC ? 490 : 520);
 				gpsTelemertieGroupLData.width = 290;
 				gpsTelemertieGroupLData.height = 170;
 				this.gpsTelemertieAlarmGroup.setLayoutData(gpsTelemertieGroupLData);
